@@ -38,6 +38,8 @@ class Client:
                 os.getenv('LOCALAPPDATA'), R'Riot Games\Riot Client\Config\lockfile')
 
         self.puuid = ""
+        self.player_name = ""
+        self.player_tag = ""
         self.lockfile = {}
         self.headers = {}
         self.local_headers = {}
@@ -66,6 +68,10 @@ class Client:
             if self.auth == {}:
                 self.lockfile = self.__get_lockfile()
                 self.puuid, self.headers, self.local_headers = self.__get_headers()
+                
+                session = self.rnet_fetch_chat_session()
+                self.player_name = session["game_name"]
+                self.player_tag = session["game_tag"]
             else:
                 self.puuid, self.headers, self.local_headers = self.auth.authenticate()
         except:
@@ -432,12 +438,14 @@ class Client:
         data = self.post(endpoint=f"/parties/v1/parties/{party_id}/invites/name/{name}/tag/{tag}",endpoint_type="glz")
         return data
 
-    def party_request_to_join(self, party_id:str) -> dict:
+    def party_request_to_join(self, party_id:str, other_puuid:str) -> dict:
         '''
         Party_RequestToJoinParty
         Requests to join a party
         '''
-        data = self.post(endpoint=f"/parties/v1/parties/{party_id}/request",endpoint_type="glz")
+        data = self.post(endpoint=f"/parties/v1/parties/{party_id}/request",endpoint_type="glz",json_data={
+            "Subjects":[other_puuid]
+        })
         return data
 
     def party_decline_request(self, request_id:str) -> dict:
